==> pysnmp-pysmi-1.0.1.tar.gz: pysnmp-pysmi-1.0.1/examples/download-and-compile-smistar-mibs-into-pysnmp-files.py <==
"""
Compile MIBs from web
+++++++++++++++++++++

Look up specific ASN.1 MIBs at configured Web and FTP sites,
compile them into pysnmp form and save Python modules as plain-text
files in a local directory.

Try to support both SMIv1 and SMIv2 flavors of SMI as well as
popular deviations from official syntax found in the wild.

In this example we disable automatic dependency checking on MIB
compilation using noDeps flag.

Also, we do not check if target file already exists thus MIB
compilation occurs on every invocation.
"""  #
from pysmi.codegen import PySnmpCodeGen
from pysmi.compiler import MibCompiler
from pysmi.parser import SmiStarParser
from pysmi.reader import FtpReader, HttpReader
from pysmi.searcher import StubSearcher
from pysmi.writer import PyFileWriter

inputMibs = ["IF-MIB", "IP-MIB"]
httpSources = [("mibs.snmplabs.com", 80, "/asn1/@mib@")]
ftpSources = [("ftp.cisco.com", "/pub/mibs/v2/@mib@")]
dstDirectory = ".pysnmp-mibs"

# Initialize compiler infrastructure

mibCompiler = MibCompiler(SmiStarParser(), PySnmpCodeGen(), PyFileWriter(dstDirectory))

# search for source MIBs at Web and FTP sites
mibCompiler.addSources(*[HttpReader(*x) for x in httpSources])
mibCompiler.addSources(*[FtpReader(*x) for x in ftpSources])

# never recompile MIBs with MACROs
mibCompiler.addSearchers(StubSearcher(*PySnmpCodeGen.baseMibs))

# run non-recursive MIB compilation
results = mibCompiler.compile(*inputMibs, **dict(noDeps=True))

print("Results: %s" % ", ".join([f"{x}:{results[x]}" for x in results]))

==> pysnmp-pysmi-1.1.0.tar.gz: pysnmp-pysmi-1.1.0/examples/download-and-compile-smistar-mibs-into-pysnmp-files.py <==
"""
Compile MIBs from web
+++++++++++++++++++++

Look up specific ASN.1 MIBs at configured Web and FTP sites,
compile them into pysnmp form and save Python modules as plain-text
files in a local directory.

Try to support both SMIv1 and SMIv2 flavors of SMI as well as
popular deviations from official syntax found in the wild.

In this example we disable automatic dependency checking on MIB
compilation using noDeps flag.

Also, we do not check if target file already exists thus MIB
compilation occurs on every invocation.
"""#
from pysmi.reader import HttpReader
from pysmi.reader import FtpReader
from pysmi.searcher import StubSearcher
from pysmi.writer import PyFileWriter
from pysmi.parser import SmiStarParser
from pysmi.codegen import PySnmpCodeGen
from pysmi.compiler import MibCompiler

inputMibs = ['IF-MIB', 'IP-MIB']
httpSources = [
    ('pysnmp.github.io', 443, '/mibs/asn1/@mib@',True)
]
ftpSources = [
    ('ftp.cisco.com', '/pub/mibs/v2/@mib@')
]
dstDirectory = '.pysnmp-mibs'

# Initialize compiler infrastructure

mibCompiler = MibCompiler(
    SmiStarParser(), PySnmpCodeGen(), PyFileWriter(dstDirectory)
)

# search for source MIBs at Web and FTP sites
mibCompiler.addSources(*[HttpReader(*x) for x in httpSources])
mibCompiler.addSources(*[FtpReader(*x) for x in ftpSources])

# never recompile MIBs with MACROs
mibCompiler.addSearchers(StubSearcher(*PySnmpCodeGen.baseMibs))

# run non-recursive MIB compilation
results = mibCompiler.compile(*inputMibs, **dict(noDeps=True))

print('Results: %s' % ', '.join(['%s:%s' % (x, results[x]) for x in results]))
